# django-sphinx-view

Serve your Sphinx docs with Django.

Please see [the project homepage for docs][homepage].

[homepage]: https://noumenal.es/django-sphinx-view/

TODO: Add contributing docs here. 
